bias_correction: Corrects given estimates for publication bias

Description Usage Arguments Value

View source: R/bias_correction.R

Description

Check package vignette for further information.

Usage

1
2
3
4
5
6
7
8
9
bias_correction(
  X,
  sigma,
  result,
  cutoffs,
  symmetric,
  identificationapproach,
  GMM
)

Arguments

X

In the case of a meta study, a n x 1 matrix containing the estimates, where n is the number of estimates. In the case of a replication study, a n x 2 matrix where the first (second) column contains the standardized original estimates (replication estimates), where n is the number of estimates.

sigma

A n x 1 matrix containing the standard errors of the estimates, where n is the number of estimates.

result

List obJect which contains the results (Psihat, Varhat, se_robust) of the publication probability estimation.

cutoffs

A matrix containing the thresholds for the steps of the publication probability. Should be strictly increasing column vector of size k x 1 where k is the number of cutoffs.

symmetric

If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed.

identificationapproach

Indication if we are dealing with replication studies (== 1) or a met analysis (== 2).

GMM

If set to TRUE, the publication probability will be estimated via GMM. Setting it to FALSE uses the MLE method for estimation.

Value

Returns a list containing the original estimates with the adjusted 95% confidence bonds (original, adj_L, adj_U) as well as the corrected estimates (adj_estimates) and in addition the Bonferroni corrected 95% confidence bonds (adj_LB, adj_UB).


t-sager/pubias documentation built on Dec. 23, 2021, 7:41 a.m.