gmm_meta: Computing the publication probability in meta analyses

Description Usage Arguments Value

View source: R/gmm_meta.R

Description

gmm_meta() calculates the publication probability, its variance and robust standard errors of meta-analyses by a Maximum Likelihood approach. Check package vignette for further information.

Usage

1
gmm_meta(X, sigma, symmetric, cluster_ID, cutoffs)

Arguments

X

A n x 1 matrix containing the estimates, where n is the number of estimates.

sigma

A n x 1 matrix containing the standard errors of the estimates, where n is the number of estimates.

symmetric

If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed.

cluster_ID

A n x 1 matrix containing IDs going from 1 to n, where n is the number of estimates.

cutoffs

A matrix containing the thresholds for the steps of the publication probability. Should be strictly increasing column vector of size k x 1 where k is the number of cutoffs.

Value

Returns a list object with the publication probability (Psihat), its variance (Varhat) and robust standard error (se_robust).


t-sager/pubias documentation built on Dec. 23, 2021, 7:41 a.m.