gmm_replication: Computing the publication probability in replication studies

Description Usage Arguments Value

View source: R/gmm_replication.R

Description

gmm_replication() calculates the publication probability, its variance and robust standard errors of meta-analyses by a GMM approach. Check package vignette for further information..

Usage

1
gmm_replication(Z, sigmaZ2, symmetric, cluster_ID, cutoffs)

Arguments

Z

A n x 2 matrix where the first (second) column contains the standardized original estimates (replication estimates), where n is the number of estimates.

sigmaZ2

A n x 1 matrix containing the standard errors (se_replication divided by se_original) of the estimates, where n is the number of estimates.

symmetric

If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed.

cluster_ID

A n x 1 matrix containing IDs going from 1 to n, where n is the number of estimates.

cutoffs

A matrix containing the thresholds for the steps of the publication probability. Should be strictly increasing column vector of size k x 1 where k is the number of cutoffs.

Value

Returns a list object with the publication probability (Psihat), its variance (Varhat) and robust standard error (se_robust).


t-sager/pubias documentation built on Dec. 23, 2021, 7:41 a.m.