Description Usage Arguments Value
View source: R/mle_replication.R
mle_replication() calculates the publication probability, its variance and robust standard errors
of replication studies by a GMM approach. Check package vignette for further information.
1 | mle_replication(Z, sigmaZ2, symmetric, cluster_ID, cutoffs, C)
|
Z |
A |
sigmaZ2 |
A |
symmetric |
If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed. |
cluster_ID |
A |
cutoffs |
A matrix containing the thresholds for the steps of the publication probability. Should be strictly increasing column
vector of size |
C |
A |
Returns a list object with the publication probability (Psihat), its variance (Varhat) and robust standard error (se_robust).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.