pubias_replication: Identification of and correction for publication bias in...

Description Usage Arguments Value

View source: R/pubias_replication.R

Description

pubias_replication() calculates the publication probability either by a Maximum Likelihood or a GMM approach and then reports the corrected estimates for a set of replication studies. Check package vignette for further information.

Usage

1
2
3
4
5
6
7
8
9
pubias_replication(
  data,
  studynames = NULL,
  symmetric = TRUE,
  sign_lvl = 0.05,
  GMM = FALSE,
  print_plots = FALSE,
  print_dashboard = FALSE
)

Arguments

data

A n x 4 matrix where the first (third) column contains the standardized original estimates (replication estimates), the second (fourth) column the associated standard errors of the standardized original estimates (replication estimates), where n is the number of estimates.

studynames

Optional. A vector of type character containing all the Studynames of size n in the same order as the argument data.

symmetric

If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed.

sign_lvl

A value indicating the significance level at which the analysis should be done. Ultimately leads to the threshold (z-score) for the steps of the publication probability. By default, the significance level is set at 5%, hence 0.05.

GMM

If set to TRUE, the publication probability will be estimated via GMM. By default, it is set to FALSE which uses the MLE method for estimation.

print_plots

If set to TRUE, descriptive plots as well as correction plots are printed into the working directory in .pdf format.

print_dashboard

If set to TRUE, additionally to the .pdf plots, a dashboard with the same charts in dynamic format is produced. The dashboard is saved in the working directory. Only possible if print_plots is set to TRUE.

Value

Returns a list object called pubias_result with the elements Results and Corrected Estimates. If specified, the list also includes the descriptive, as well as the correction plots as ggplot objects.

Results contains the publication probability (Psihat), its variance (Varhat) and robust standard error (se_robust).

Corrected Estimates contains the original estimates and the median unbiased estimates (original, adj_estimates) as well as the corrected 95% confidence bounds (adj_L, adj_U). In addition, the Bonferroni corrected 95% confidence bounds are reported (adj_LB, adj_UB).


t-sager/pubias documentation built on Dec. 23, 2021, 7:41 a.m.