Description Usage Arguments Value
View source: R/bias_correction.R
Check package vignette for further information.
1 2 3 4 5 6 7 8 9 | bias_correction(
X,
sigma,
result,
cutoffs,
symmetric,
identificationapproach,
GMM
)
|
X |
In the case of a meta study, a |
sigma |
A |
result |
List obJect which contains the results ( |
cutoffs |
A matrix containing the thresholds for the steps of the publication probability. Should be strictly increasing column
vector of size |
symmetric |
If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed. |
identificationapproach |
Indication if we are dealing with replication studies (== 1) or a met analysis (== 2). |
GMM |
If set to TRUE, the publication probability will be estimated via GMM. Setting it to FALSE uses the MLE method for estimation. |
Returns a list containing the original estimates with the adjusted 95% confidence bonds (original, adj_L, adj_U)
as well as the corrected estimates (adj_estimates) and in addition the Bonferroni corrected 95% confidence bonds (adj_LB, adj_UB).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.