Description Usage Arguments Value
gmm_meta() calculates the publication probability, its variance and robust standard errors
of meta-analyses by a Maximum Likelihood approach. Check package vignette for further information.
1 |
X |
A |
sigma |
A |
symmetric |
If set to TRUE, the publication probability is assumed to be symmetric around zero. If set to FALSE, asymmetry is allowed. |
cluster_ID |
A |
cutoffs |
A matrix containing the thresholds for the steps of the publication probability. Should be strictly increasing column
vector of size |
Returns a list object with the publication probability (Psihat), its variance (Varhat) and robust standard error (se_robust).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.