Description Usage Arguments Value
View source: R/pubias_replication.R
pubias_replication() calculates the publication probability either by a Maximum Likelihood or a GMM approach and
then reports the corrected estimates for a set of replication studies. Check package vignette for further information.
1 2 3 4 5 6 7 8 9 |
data |
A |
studynames |
Optional. A vector of type |
symmetric |
If set to |
sign_lvl |
A value indicating the significance level at which the analysis should be done. Ultimately leads to the threshold (z-score) for the steps of the publication probability.
By default, the significance level is set at 5%, hence |
GMM |
If set to |
print_plots |
If set to |
print_dashboard |
If set to |
Returns a list object called pubias_result with the elements Results and Corrected Estimates.
If specified, the list also includes the descriptive, as well as the correction plots as ggplot objects.
Results contains the publication probability (Psihat), its variance (Varhat) and robust standard error (se_robust).
Corrected Estimates contains the original estimates and the median unbiased estimates (original, adj_estimates) as well as the corrected 95% confidence bounds (adj_L, adj_U). In addition, the Bonferroni corrected 95% confidence bounds are reported (adj_LB, adj_UB).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.